summaryrefslogtreecommitdiffstats
path: root/Graphics/GraphicsEngine
diff options
context:
space:
mode:
authorEgor Yusov <egor.yusov@gmail.com>2018-03-30 16:52:13 +0000
committerEgor Yusov <egor.yusov@gmail.com>2018-03-30 16:52:13 +0000
commit5677bdafc48e6231a67c01e5d894ed657aa0ecf6 (patch)
treea847157bc1d7f8811bcae2d37e9ebe1f8f9b4c6b /Graphics/GraphicsEngine
parentImplemented option to specify hardware adapter when initializing the engine i... (diff)
downloadDiligentCore-5677bdafc48e6231a67c01e5d894ed657aa0ecf6.tar.gz
DiligentCore-5677bdafc48e6231a67c01e5d894ed657aa0ecf6.zip
Implemented initialization in fullscreen mode on Win32
Diffstat (limited to 'Graphics/GraphicsEngine')
-rw-r--r--Graphics/GraphicsEngine/interface/GraphicsTypes.h27
1 files changed, 25 insertions, 2 deletions
diff --git a/Graphics/GraphicsEngine/interface/GraphicsTypes.h b/Graphics/GraphicsEngine/interface/GraphicsTypes.h
index 574e4c12..59bd356c 100644
--- a/Graphics/GraphicsEngine/interface/GraphicsTypes.h
+++ b/Graphics/GraphicsEngine/interface/GraphicsTypes.h
@@ -986,8 +986,11 @@ namespace Diligent
/// Display format
TEXTURE_FORMAT Format = TEX_FORMAT_UNKNOWN;
- /// Display refresh rate
- double RefreshRate = 0.0;
+ /// Refresh rate numerator
+ Uint32 RefreshRateNumerator = 0;
+
+ /// Refresh rate denominator
+ Uint32 RefreshRateDenominator = 0;
/// The scanline drawing mode.
SCALING Scaling = SCALING_UNSPECIFIED;
@@ -1036,6 +1039,26 @@ namespace Diligent
{}
};
+ /// Full screen mode description
+ /// \sa <a href = "https://msdn.microsoft.com/en-us/library/windows/desktop/hh404531(v=vs.85).aspx">DXGI_SWAP_CHAIN_FULLSCREEN_DESC structure on MSDN</a>,
+ struct FullScreenModeDesc
+ {
+ /// A Boolean value that specifies whether the swap chain is in fullscreen mode.
+ Bool Fullscreen = False;
+
+ /// Refresh rate numerator
+ Uint32 RefreshRateNumerator = 0;
+
+ /// Refresh rate denominator
+ Uint32 RefreshRateDenominator = 0;
+
+ /// The scanline drawing mode.
+ DisplayModeAttribs::SCALING Scaling = DisplayModeAttribs::SCALING_UNSPECIFIED;
+
+ /// The scaling mode.
+ DisplayModeAttribs::SCANLINE_ORDER ScanlineOrder = DisplayModeAttribs::SCANLINE_ORDER_UNSPECIFIED;
+ };
+
/// Engine creation attibutes
struct EngineCreationAttribs
{